MapMarker class

Constructors

MapMarker(double height, double width, LatitudeLongitude point, Widget builder(BuildContext))

Properties

builder Widget Function(BuildContext)
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
point LatitudeLongitude
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited